Re:The State of Fortran
by adgjlsfhk1 on Thursday April 07, 2022 @11:59AM
(#30946277)
The naive Julia code made a few pretty fundamental mistakes (Complex vs Complex{Float64}, and row vs column major). The following is non-optimized Julia code that is roughly 6x faster (and much simpler) than the "optimized" code in the blogpost. Some further optimizations would give another 2-4x over this (like using StaticArrays), but I'll leave that as an exercise for the reader.
[ Parent
| on HN ]
There are no comments on this comment yet.